@@ -1,5 +1,5 @@
-#!/usr/pkg/bin/python2.7
-'''
+#!/21Q1/bin/python3.8
+"""
 NAME
     unwraplatex - Removes delimiters from LaTeX source text
 
@@ -8,11 +8,17 @@ SYNOPSIS
 
 DESCRIPTION
     This filter reads LaTeX source text from STDIN and removes the
-    surrounding \[ and \] delimiters.
-'''
+    surrounding \\[ and \\] delimiters.
+"""
 
-import re, sys
+import re
+import sys
 
-sys.stdout.write(re.sub("(?s)\A(?:\\\\\[\s*)?(.*?)(?:\\\\\])?\Z", "\\1", sys.stdin.read().rstrip()))
+sys.stdout.write(
+    re.sub(
+        r"(?s)\A(?:\\\[\s*)?(.*?)(?:\\\])?\Z", "\\1",
+        sys.stdin.read().rstrip()
+    )
+)
 # NOTE append endline in result to prevent 'no output from filter' warning
 sys.stdout.write("\n")
